/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar & Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 */
package nl.esi.metis.aisparser;

/** This interface represents an AIS message of type 27: Long-range AIS broadcast message.
*
* @author Pierre van de Laar
* @author Pierre America
* @author Brian C. Lane
*/
public interface AISMessage27 extends AISMessage {

	/** positionAccuracy
	 * @return boolean value of positionAccuracy (bit 39)
	 */
	public boolean getPositionAccuracy();

	/** raimFlag
	 * @return boolean value of raimFlag (bit 40)
	 */
	public boolean getRaimFlag();

	/** navigationalStatus
	 * @return int value of navigationalStatus (4 bits [41,44])
	 */
	public int getNavigationalStatus();

	/** longitude (18 bits)
	 * @return int value of longitude (18 bits [45,62])
	 */
	public int getLongitude();

	/** Returns the latitude. This value can be analyzed further with utility class {@link UtilsLatitude17}.
	 * @return an integer value representing the latitude in 1/10 minute (&plusmn;90&deg;, North = positive, South = negative).
	 */
	public int getLatitude();

	/** speedOverGround (6 bits)
	 * @return int value of speedOverGround (6 bits [80,85])
	 */
	public int getSpeedOverGround();

	/** courseOverGround (9 bits)
	 * @return int value of courseOverGround (9 bits [86,94])
	 */
	public int getCourseOverGround();

	/** statusOfCurrentGNSSPosition
	 * @return boolean value of statusOfCurrentGNSSPosition (bit 95)
	 */
	public boolean getStatusOfCurrentGNSSPosition();

	/** spare
	 * @return int value of spare (1 bits [96,96])
	 */
	public int getSpare();

}