package nl.esi.metis.aisparser;
/** ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 * @author Pierre van de Laar
 * @author Brian C. Lane
 */

//TODO also store content of inconsistent message?

/** AIS Message Inconsistent
 * Class to store AIS Messages that don't adhere to the standard
 */
class AISMessageIllegalImpl implements AISMessageIllegal {
	private static final int MESSAGEID_FROM = 1;
	private static final int MESSAGEID_TO = 6;

	private int messageID;
	/** messageID
	 * @return int value of messageID (6 bits [1,6])
	 */
	public int getMessageID() { return messageID; }


	private static final int REPEATINDICATOR_FROM = 7;
	private static final int REPEATINDICATOR_TO = 8;

	private int repeatIndicator;
	/** repeatIndicator
	 * @return int value of repeatIndicator (2 bits [7,8])
	 */
	public int getRepeatIndicator() { return repeatIndicator; }


	private static final int USERID_FROM = 9;
	private static final int USERID_TO = 38;

	private int userID;
	/** userID
	 * @return int value of userID (30 bits [9,38])
	 */
	public int getUserID() { return userID; }
	

	/** The provenance */
	private Provenance provenance;
	
	/** Returns the provenance, i.e., a description of where the AIS message came from, including a time stamp.
	 * @return the provenance
	 */
	public Provenance getProvenance() {
		return provenance;
	}
	
    /** Constructs an object representing an illegal message.
     * @param content the content of the message
     * @param prov the provenance of the message
     */
	public AISMessageIllegalImpl(Sixbit content, Provenance prov)
	{
    	assert(content.length() < USERID_TO);
    	
    	if (content.length() >= MESSAGEID_TO)
    	{
    		messageID = content.getIntFromTo(MESSAGEID_FROM,MESSAGEID_TO);
    	}	
    	if (content.length() >= REPEATINDICATOR_TO)
    	{
    		repeatIndicator = content.getIntFromTo(REPEATINDICATOR_FROM,REPEATINDICATOR_TO);
    	}
    	if (content.length() >= USERID_FROM)
    	{
    		//best I can think of
    		userID = content.getIntFromTo(USERID_FROM,content.length());
    	}
    	
    	this.provenance = prov;
	}

    /**
     * Generates a String representing the parsed AISMessage 
     * Format:
     * all fields are shown in the order and units as specified by the standard separated by SEPARATORs
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
    	return  Integer.toString(messageID) + AISMessageImpl.SEPARATOR +
    			Integer.toString(repeatIndicator) + AISMessageImpl.SEPARATOR +
    			Integer.toString(userID) + AISMessageImpl.SEPARATOR ;
    }
}