/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar & Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 */
package nl.esi.metis.aisparser;

/** An object of this class indicates that information is contained in an AIVDM message that was obtained from one or more sources together.
 * @author Pierre America
 * @author Pierre van de Laar
 */
public class AIVDMMessageCombination implements Provenance {

	/** The time when the information was created. */
	private double time;

	/** Returns the time stamp when the information item was created. */
	public double getTime() {
		return time;
	}

	/** Returns a description of the provenance of the information item. 
	 * In this case, it mentions the sources that are combined to form the current AIVDM message. */
	public String getProvenanceTree(String layout) {
		StringBuilder sb = new StringBuilder(layout + "AIVDMMessage combines\n");
		final String newLayout = layout + " - ";
		for(Provenance p : parts)
		{
			if(p == null)
			{
				sb.append(newLayout + "null\n");
			}
			else
			{
				sb.append(p.getProvenanceTree(newLayout) +"\n");
			}
		}
		return sb.toString();
	}

	/** This array contains the provenance objects for all the parts of the AIVDM message */
	private Provenance[] parts;
	
	/** Returns the provenance objects for all the parts of the AIVDM message. */
	public Provenance[] getParts ()  {
		return parts;
	}
	
	/** Constructs a provenance object describing an AIVDM message that was obtained from one or more sources together.
	 * @param p the provenance objects for all the parts of the AIVDM message
	 */
	public AIVDMMessageCombination (Provenance[] p)
	{
		parts = p;
		
		//bounded linear search to find first time
		int x = 0;
		int y = p.length;
		while(x != y)
		{
			if(p[x]== null)
			{
				x++;
			}
			else
			{
				y=x;
			}
		}
		if(x < p.length)
		{
			time = p[x].getTime();
		}
		else
		{
			time = 0;
		}
	}
}
