package nl.esi.metis.aisparser;
/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar, Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 */

/** This class represents the destination area that is returned by {@link AISMessage22#getDestination} or {@link AISMessage23#getDestinationArea()}.
 * @author Pierre van de Laar
 * @author Pierre America
 * @author Brian C. Lane
 */
public class DestinationArea extends Destination {
	private int       	   lon_UR;               // 18 bits : Long minutes/10	Upper Right corner (north east)
	private int       	   lat_UR;               // 17 bits : Lat minutes/10    Upper Right corner (north east)
	private int       	   lon_LL;               // 18 bits : Long minutes/10	Lower Left corner (South West)
	private int       	   lat_LL;               // 17 bits : Lat minutes/10    Lower Left corner (South West)

	/** Returns the longitude of the upper right corner of the area. This value can be analyzed further with utility class {@link UtilsLongitude18}.
	 * @return an integer value representing the longitude in 1/10 minute (&plusmn;90&deg;, North = positive, South = negative).
	 */
	public int longitudeUpperRightCorner() { return this.lon_UR; }

	/** Returns the latitude of the upper right corner of the area. This value can be analyzed further with utility class {@link UtilsLatitude17}.
	 * @return an integer value representing the latitude in 1/10 minute (&plusmn;90&deg;, North = positive, South = negative).
	 */
	public int latitudeUpperRightCorner() { return this.lat_UR; }

	/** Returns the longitude of the lower left corner of the area. This value can be analyzed further with utility class {@link UtilsLongitude18}.
	 * @return an integer value representing the longitude in 1/10 minute (&plusmn;90&deg;, North = positive, South = negative).
	 */
	public int longitudeLowerLeftCorner() { return this.lon_LL; }

	/** Returns the latitude of the lower left corner of the area. This value can be analyzed further with utility class {@link UtilsLatitude17}.
	 * @return an integer value representing the latitude in 1/10 minute (&plusmn;90&deg;, North = positive, South = negative).
	 */
	public int latitudeLowerLeftCorner() { return this.lat_LL; }

	/** Constructs a <code>DestinationArea</code> object.
	 * This constructor is used in the implementation classes {@link AISMessage22Impl} and {@link AISMessage23Impl}.
	 * @param offset the offset from the beginning of the AIS message where the destination area starts.
	 * @param content the content of the AIS message
	 */
	public DestinationArea (int offset, Sixbit content)
	{
		lat_UR = content.getIntFromTo(offset, offset+17);
		lon_UR = content.getIntFromTo(offset+18, offset+34);
		
		lat_LL = content.getIntFromTo(offset+35, offset+52);
		lon_LL = content.getIntFromTo(offset+53, offset+69);
	}
}
